@@ -15,7 +15,7 @@ def plot_multiple_drawdowns(data_df, column_names):
         trace_sig = go.Scatter(
             x=data_df.index,
             y=data_df[column_name],
-            name=f'drawdown {column_name}',
+            name=f'{column_name}',
             opacity=0.8)
         fig.append_trace(trace_sig, row=1, col=1)
     fig.update_layout(height=600, width=1600, title_text="Drawdown chart",showlegend=True)
